searchData={"items":[{"type":"module","title":"ExCycle","doc":"Documentation for `ExCycle`.","ref":"ExCycle.html"},{"type":"function","title":"ExCycle.add_rule/3","doc":"Adds a new rule using a frequency.\n\nThe frequency could be one of: `:secondly`, `:minutely`, `:hourly`, `:daily`, `:weekly`, `:monthly` or `:yearly`.","ref":"ExCycle.html#add_rule/3"},{"type":"function","title":"Options - ExCycle.add_rule/3","doc":"- `:interval`: the interval of the frequency (`interval: 2` will generate a `x + n * 2` result)\n- `:hours`: set a restricted on hours of the day (`hours: [20, 10]` will generate every \"frequency\" at \"10:00\" and \"20:00\")","ref":"ExCycle.html#add_rule/3-options"},{"type":"function","title":"Examples - ExCycle.add_rule/3","doc":"iex> add_rule(%ExCycle{rules: []}, :daily, interval: 2, hours: [20, 10])\n    %ExCycle.Rule{\n      validations: [\n        %ExCycle.Validations.HourOfDay{hours: [10, 20]},\n        %ExCycle.Validations.Interval{frequency: :daily, value: 2},\n        ...\n      ],\n      ...\n    }","ref":"ExCycle.html#add_rule/3-examples"},{"type":"function","title":"ExCycle.new/0","doc":"Defines a new ExCycle struct.","ref":"ExCycle.html#new/0"},{"type":"function","title":"Examples - ExCycle.new/0","doc":"iex> new()\n    %ExCycle{}","ref":"ExCycle.html#new/0-examples"},{"type":"function","title":"ExCycle.occurrences/2","doc":"Creates a stream of occurrences using the `from` as reference.","ref":"ExCycle.html#occurrences/2"},{"type":"function","title":"Examples - ExCycle.occurrences/2","doc":"iex> cycle =\n    ...>   new()\n    ...>   |> add_rule(:daily, interval: 2, hours: [20, 10])\n    ...>   |> add_rule(:daily, interval: 1, hours: [15])\n    ...>   |> occurrences(~D[2024-02-29])\n    ...>   |> Enum.take(9)\n    [\n       ~N[2024-02-29 10:00:00],\n       ~N[2024-02-29 15:00:00],\n       ~N[2024-02-29 20:00:00],\n       ~N[2024-03-01 15:00:00],\n       ~N[2024-03-02 10:00:00],\n       ~N[2024-03-02 15:00:00],\n       ~N[2024-03-02 20:00:00],\n       ~N[2024-03-03 15:00:00],\n       ~N[2024-03-04 10:00:00]\n    ]","ref":"ExCycle.html#occurrences/2-examples"},{"type":"type","title":"ExCycle.datetime/0","doc":"","ref":"ExCycle.html#t:datetime/0"},{"type":"type","title":"ExCycle.t/0","doc":"","ref":"ExCycle.html#t:t/0"},{"type":"module","title":"ExCycle.Rule","doc":"Representation of a RRule following RFC 5455 (not fully compatible for the moment).","ref":"ExCycle.Rule.html"},{"type":"function","title":"ExCycle.Rule.init/2","doc":"Initializes the rule starting from the `from` datetime.","ref":"ExCycle.Rule.html#init/2"},{"type":"function","title":"Examples - ExCycle.Rule.init/2","doc":"iex> init(%Rule{}, ~D[2024-01-01])\n    %ExCycle{}\n\n    iex> init(%Rule{}, ~N[2024-01-01 10:00:00])\n    %ExCycle{}","ref":"ExCycle.Rule.html#init/2-examples"},{"type":"function","title":"ExCycle.Rule.new/2","doc":"Defines a new Rule struct.","ref":"ExCycle.Rule.html#new/2"},{"type":"function","title":"Options - ExCycle.Rule.new/2","doc":"- `duration`: a simple `Duration` struct.\n- `count`: the maximum number of recurrences to generate (default: `nil`).\n- `until`: the end date and time for the recurrence. If an occurrence coincides exactly with the `until` timestamp,\n  it will be included in the set of generated occurrences.\n- `interval`: base interval of the recurren rule (daily, weekly ....).\n- `start_at`: Reference date to used to every recurrent event generated.\n- `timezone`: TimeZone to use when generating recurrent dates.","ref":"ExCycle.Rule.html#new/2-options"},{"type":"function","title":"Examples - ExCycle.Rule.new/2","doc":"iex> new(:daily, hours: [20, 10])\n    %ExCycle.Rule{\n      validations: [\n        %ExCycle.Validations.HourOfDay{hours: [10, 20]},\n        %ExCycle.Validations.Interval{frequency: :daily, value: 1},\n        %ExCycle.Validations.DateValidation{},\n        %ExCycle.Validations.Lock{unit: :minute},\n        %ExCycle.Validations.Lock{unit: :second}\n      ],\n      timezone: nil,\n      count: nil,\n      until: nil,\n      state: %ExCycle.State{}\n    }\n\n    iex> new(:daily, hours: [20, 10], starts_at: ~N[2024-04-22 17:00:00], timezone: \"America/Montreal\")\n    %ExCycle.Rule{\n      validations: [\n        %ExCycle.Validations.HourOfDay{hours: [10, 20]},\n        %ExCycle.Validations.Interval{frequency: :daily, value: 1},\n        %ExCycle.Validations.DateValidation{},\n        %ExCycle.Validations.Lock{unit: :minute},\n        %ExCycle.Validations.Lock{unit: :second}\n      ],\n      timezone: \"America/Montreal\",\n      count: nil,\n      until: nil,\n      state: %ExCycle.State{starts_at: ~N[2024-04-22 17:00:00]}\n    }","ref":"ExCycle.Rule.html#new/2-examples"},{"type":"function","title":"ExCycle.Rule.next/1","doc":"Returns the next dates that match validations.","ref":"ExCycle.Rule.html#next/1"},{"type":"function","title":"Examples - ExCycle.Rule.next/1","doc":"iex> rule =\n    ...>   Rule.new(:daily, interval: 2, hours: [20, 10])\n    ...>   |> Map.put(:state, ExCycle.State.new(~D[2024-04-04]))\n    ...> rule = Rule.next(rule)\n    %Rule{state: %ExCycle.State{next: ~N[2024-04-04 10:00:00]}}","ref":"ExCycle.Rule.html#next/1-examples"},{"type":"type","title":"ExCycle.Rule.t/0","doc":"","ref":"ExCycle.Rule.html#t:t/0"},{"type":"module","title":"ExCycle.Span","doc":"`Span` is used to generate datetime with a Rule that contain a `Duration`.\nWhen a `duration` is specified, we must have a `from` and a `to` for every generated datetimes.","ref":"ExCycle.Span.html"},{"type":"function","title":"ExCycle.Span.new/2","doc":"","ref":"ExCycle.Span.html#new/2"},{"type":"type","title":"ExCycle.Span.t/0","doc":"","ref":"ExCycle.Span.html#t:t/0"},{"type":"module","title":"ExCycle.State","doc":"The `ExCycle.State` represents the state of the next generated datetime.","ref":"ExCycle.State.html"},{"type":"function","title":"ExCycle.State.apply_duration/2","doc":"","ref":"ExCycle.State.html#apply_duration/2"},{"type":"function","title":"ExCycle.State.apply_timezone/2","doc":"","ref":"ExCycle.State.html#apply_timezone/2"},{"type":"function","title":"ExCycle.State.check_exhaust/2","doc":"","ref":"ExCycle.State.html#check_exhaust/2"},{"type":"function","title":"ExCycle.State.new/1","doc":"Creates a new state.\nThe `next` dates will be the same as `origin`.","ref":"ExCycle.State.html#new/1"},{"type":"function","title":"Examples - ExCycle.State.new/1","doc":"iex> new(~D[2024-01-01])\n    %ExCycle.State{origin: ~N[2024-01-01 00:00:00], next: ~N[2024-01-01 00:00:00]}\n\n    iex> new(~N[2024-01-01 10:00:00])\n    %ExCycle.State{origin: ~N[2024-01-01 10:00:00], next: ~N[2024-01-01 10:00:00]}","ref":"ExCycle.State.html#new/1-examples"},{"type":"function","title":"ExCycle.State.new/2","doc":"Creates a new state specifying the `origin` and the `next` (aka `from` is this context).","ref":"ExCycle.State.html#new/2"},{"type":"function","title":"Examples - ExCycle.State.new/2","doc":"iex> new(~D[2024-01-01], ~D[2024-02-02])\n    %ExCycle.State{origin: ~N[2024-01-01 00:00:00], next: ~N[2024-02-02 00:00:00]}\n\n    iex> new(~N[2024-01-01 10:00:00], ~D[2024-02-02])\n    %ExCycle.State{origin: ~N[2024-01-01 10:00:00], next: ~N[2024-02-02 00:00:00]}\n\n    iex> new(~N[2024-01-01 10:00:00], ~N[2024-02-02 10:00:00])\n    %ExCycle.State{origin: ~N[2024-01-01 10:00:00], next: ~N[2024-02-02 10:00:00]}","ref":"ExCycle.State.html#new/2-examples"},{"type":"function","title":"ExCycle.State.reset/1","doc":"Resets the state.\n\nBy resetting, we means set the `origin` value equal to `next` value.","ref":"ExCycle.State.html#reset/1"},{"type":"function","title":"Examples - ExCycle.State.reset/1","doc":"iex> reset(%ExCycle.State{origin: ~N[2024-03-01 00:00:00], next: ~N[2024-06-01 00:00:00]})\n    %ExCycle.State{origin: ~N[2024-06-01 00:00:00], next: ~N[2024-06-01 00:00:00]}","ref":"ExCycle.State.html#reset/1-examples"},{"type":"function","title":"ExCycle.State.set_next/2","doc":"","ref":"ExCycle.State.html#set_next/2"},{"type":"function","title":"ExCycle.State.set_result/1","doc":"","ref":"ExCycle.State.html#set_result/1"},{"type":"function","title":"ExCycle.State.update_next/2","doc":"`update_next/3` is an helper to update the next value.","ref":"ExCycle.State.html#update_next/2"},{"type":"type","title":"ExCycle.State.datetime/0","doc":"","ref":"ExCycle.State.html#t:datetime/0"},{"type":"type","title":"ExCycle.State.t/0","doc":"","ref":"ExCycle.State.html#t:t/0"},{"type":"behaviour","title":"ExCycle.Validations","doc":"Every Rules applies a list of validation to defined the next datetime.\n\nThoses validations could be:\n\n- `interval` (required)\n- `hour_of_day` (optional)","ref":"ExCycle.Validations.html"},{"type":"callback","title":"ExCycle.Validations.next/2","doc":"","ref":"ExCycle.Validations.html#c:next/2"},{"type":"callback","title":"ExCycle.Validations.valid?/2","doc":"","ref":"ExCycle.Validations.html#c:valid?/2"},{"type":"type","title":"ExCycle.Validations.any_validation/0","doc":"","ref":"ExCycle.Validations.html#t:any_validation/0"},{"type":"module","title":"ExCycle.Validations.DateExclusion","doc":"DateExclusion defines a list of date or datetime to exclude from generated datetimes.","ref":"ExCycle.Validations.DateExclusion.html"},{"type":"module","title":"Examples - ExCycle.Validations.DateExclusion","doc":"iex> %DateExclusion{dates: [~D[2024-01-01], ~N[2024-01-02 10:00:00]]}\n\nWill exclude the date 2024-01-01 and the datetime 2024-01-02 10:00:00.","ref":"ExCycle.Validations.DateExclusion.html#module-examples"},{"type":"function","title":"ExCycle.Validations.DateExclusion.new/1","doc":"","ref":"ExCycle.Validations.DateExclusion.html#new/1"},{"type":"type","title":"ExCycle.Validations.DateExclusion.t/0","doc":"","ref":"ExCycle.Validations.DateExclusion.html#t:t/0"},{"type":"module","title":"ExCycle.Validations.DateValidation","doc":"`DateValidation` ensure the generated date is a valid dates.\nThis is usefull for leap year and not leap year (e.g. 2023-02-29 doesn't exist wheras 2024-02-29 do).","ref":"ExCycle.Validations.DateValidation.html"},{"type":"function","title":"ExCycle.Validations.DateValidation.new/0","doc":"","ref":"ExCycle.Validations.DateValidation.html#new/0"},{"type":"type","title":"ExCycle.Validations.DateValidation.t/0","doc":"","ref":"ExCycle.Validations.DateValidation.html#t:t/0"},{"type":"module","title":"ExCycle.Validations.Days","doc":"Days defines a list of day (day in the week, like monday, tuesday ...) to use in the generated time.","ref":"ExCycle.Validations.Days.html"},{"type":"module","title":"Examples - ExCycle.Validations.Days","doc":"iex> %Days{days: [:monday]}\n    # will generate datetimes every monday\n\n    iex> %Days{days_by_week: [{-1, :monday}, {2, :saturday}]}\n    # will generate datetimes every last monday and every second saturday of the month\n\n    iex> %Days{days: [:monday], days_by_week: [{1, :tuesday}]}\n    # Will generate datetimes every monday and every first tuesday of the month","ref":"ExCycle.Validations.Days.html#module-examples"},{"type":"function","title":"ExCycle.Validations.Days.new/1","doc":"","ref":"ExCycle.Validations.Days.html#new/1"},{"type":"type","title":"ExCycle.Validations.Days.day/0","doc":"","ref":"ExCycle.Validations.Days.html#t:day/0"},{"type":"type","title":"ExCycle.Validations.Days.t/0","doc":"","ref":"ExCycle.Validations.Days.html#t:t/0"},{"type":"type","title":"ExCycle.Validations.Days.week/0","doc":"","ref":"ExCycle.Validations.Days.html#t:week/0"},{"type":"module","title":"ExCycle.Validations.DaysOfMonth","doc":"DaysOfMonth defines a list of day (number of the day in the month) to use in the generated datetime.","ref":"ExCycle.Validations.DaysOfMonth.html"},{"type":"module","title":"Examples - ExCycle.Validations.DaysOfMonth","doc":"iex> %DaysOfMonth{days: [1, 10]}\n\nwill generate datetime every 1st and 10th of the month.","ref":"ExCycle.Validations.DaysOfMonth.html#module-examples"},{"type":"function","title":"ExCycle.Validations.DaysOfMonth.new/1","doc":"","ref":"ExCycle.Validations.DaysOfMonth.html#new/1"},{"type":"type","title":"ExCycle.Validations.DaysOfMonth.t/0","doc":"","ref":"ExCycle.Validations.DaysOfMonth.html#t:t/0"},{"type":"module","title":"ExCycle.Validations.HourOfDay","doc":"HourOfDay defines a list of specific hours to use in the generated datetime.","ref":"ExCycle.Validations.HourOfDay.html"},{"type":"module","title":"Examples - ExCycle.Validations.HourOfDay","doc":"iex> %HourOfDay{hours: [10, 20]}\n\nwill generate datetime every 10:00 and 20:00 of the interval specified (e.g. `daily`).","ref":"ExCycle.Validations.HourOfDay.html#module-examples"},{"type":"function","title":"ExCycle.Validations.HourOfDay.new/1","doc":"","ref":"ExCycle.Validations.HourOfDay.html#new/1"},{"type":"type","title":"ExCycle.Validations.HourOfDay.t/0","doc":"","ref":"ExCycle.Validations.HourOfDay.html#t:t/0"},{"type":"module","title":"ExCycle.Validations.Interval","doc":"Interval is the base of RRule. Every Rule could be:\n\n- `secondly`\n- `minutely`\n- `hourly`\n- `daily`\n- `weekly`\n- `montly`\n- `yearly`","ref":"ExCycle.Validations.Interval.html"},{"type":"function","title":"ExCycle.Validations.Interval.new/2","doc":"","ref":"ExCycle.Validations.Interval.html#new/2"},{"type":"type","title":"ExCycle.Validations.Interval.frequency/0","doc":"","ref":"ExCycle.Validations.Interval.html#t:frequency/0"},{"type":"type","title":"ExCycle.Validations.Interval.t/0","doc":"","ref":"ExCycle.Validations.Interval.html#t:t/0"},{"type":"module","title":"ExCycle.Validations.Lock","doc":"The `Lock` validation is used to lock a specific item like `:day`.\nSo the generated datetime MUST have the valid datetime that match this restriction.","ref":"ExCycle.Validations.Lock.html"},{"type":"function","title":"ExCycle.Validations.Lock.new/1","doc":"","ref":"ExCycle.Validations.Lock.html#new/1"},{"type":"type","title":"ExCycle.Validations.Lock.t/0","doc":"","ref":"ExCycle.Validations.Lock.html#t:t/0"},{"type":"type","title":"ExCycle.Validations.Lock.unit/0","doc":"","ref":"ExCycle.Validations.Lock.html#t:unit/0"},{"type":"module","title":"ExCycle.Validations.MinuteOfHour","doc":"MinuteOfHour defines a list of specific minutes to use in the generated datetime.","ref":"ExCycle.Validations.MinuteOfHour.html"},{"type":"module","title":"Examples - ExCycle.Validations.MinuteOfHour","doc":"iex> %MinuteOfHour{minutes: [0, 15, 30, 45]}\n\nwill generate datetime hour at XX:00, XX:15, XX:30 and XX:45.","ref":"ExCycle.Validations.MinuteOfHour.html#module-examples"},{"type":"function","title":"ExCycle.Validations.MinuteOfHour.new/1","doc":"","ref":"ExCycle.Validations.MinuteOfHour.html#new/1"},{"type":"type","title":"ExCycle.Validations.MinuteOfHour.t/0","doc":"","ref":"ExCycle.Validations.MinuteOfHour.html#t:t/0"},{"type":"module","title":"Duration","doc":"This is mainly to create a struct introduces in Elixir v1.17.0\nhttps://github.com/elixir-lang/elixir/blob/main/lib/elixir/lib/calendar/duration.ex","ref":"Duration.html"},{"type":"type","title":"Duration.t/0","doc":"The duration struct type.","ref":"Duration.html#t:t/0"},{"type":"extras","title":"ExCycle","doc":"# ExCycle\n\n`ExCycle` is a powerful library to generate datetimes following RRules from iCalendar.\n\n```elixir\niex> ExCycle.new()\n...> |> ExCycle.add_rule(:daily, interval: 2, hours: [20, 10]\n...> |> ExCycle.add_rule(:daily, interval: 1, hours: [15]\n...> |> ExCycle.occurrences(~D[2024-02-29]\n...> |> Enum.take(5)\n[~N[2024-02-29 10:00:00], ~N[2024-02-29 15:00:00], ~N[2024-02-29 20:00:00], ~N[2024-03-01 15:00:00], ~N[2024-03-02 10:00:00]]\n```","ref":"readme.html"},{"type":"extras","title":"Installation - ExCycle","doc":"`ExCycle` is available on [Hex](https://hex.pm/packages/ex_cycle) and can be installed\nby adding `ex_cycle` to your list of dependencies in `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:ex_cycle, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Time zone database - ExCycle","doc":"ExCycle support timezones and require a time zone database.\nBy default, it uses the default time zone database returned by\n`Calendar.get_time_zone_database/0`, which defaults to\n`Calendar.UTCOnlyTimeZoneDatabase` which only handles \"Etc/UTC\"\ndatetimes and returns `{:error, :utc_only_time_zone_database}`\nfor any other time zone.\n\nOther time zone databases can also be configured. For example,\ntwo of the available options are:\n\n* [`tz`](https://hexdocs.pm/tz/)\n* [`tzdata`](https://hexdocs.pm/tzdata/)\n\nTo use them, first make sure it is added as a dependency in `mix.exs`.\nIt can then be configured either via configuration:\n\n```elixir\nconfig :elixir, :time_zone_database, Tzdata.TimeZoneDatabase\n```\n\nor by calling `Calendar.put_time_zone_database/1`:\n\n```elixir\nCalendar.put_time_zone_database(Tzdata.TimeZoneDatabase)\n```\n\nSee the proper names in the library installation instructions.\n\n> We apply the same logic as [DateTime from elixir](https://hexdocs.pm/elixir/DateTime.html).","ref":"readme.html#time-zone-database"},{"type":"extras","title":"Documentation - ExCycle","doc":"Full documentation could be found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"Quick-start Guide - ExCycle","doc":"Create a *cycle* and add rules\n\n```elixir\nExCycle.new()\n|> ExCycle.add_rule(:daily, hours: [20, 10])\n|> ExCycle.add_rule(:daily, interval: 2, hours: [15])\n\n# Generates every day at 10:00 and 20:00 and every 2 days at 15:00\n```\n\nThe first element is the frequency that could be one of `secondly`, `minutely`, `hourly`,\n`daily`, `monthly` or `yearly`. Then the 2nd parameter is a list of validations options\n(like every hours at X).\n\nYou can specified a duration using the option `:duration`. The value uses the `Duration` structured, introduced\nin elixir `1.17`.\n\n> For every Elixir's versions before `1.17`, we have been cloned this structure to obtain the same behaviour.","ref":"readme.html#quick-start-guide"},{"type":"extras","title":"Options - ExCycle","doc":"Here the list of option that you can use to generate the rule (using `ExCycle.add_rule/3`).\n\n- `:interval`\n- `:hours`\n- `:minutes`","ref":"readme.html#options"},{"type":"extras","title":"Timezones - ExCycle","doc":"As we mention earlier, we support timezone and you can easily generate datetime using the option `timezone: \"America/Montreal\"` as the code bellow.\n\n```elixir\nExCycle.new()\n|> ExCycle.add_rule(:daily, hours: [20, 10], timezone: \"America/Montreal\")\n\n# Generates every day at 10:00 and 20:00 with timezone America/Montreal\n```","ref":"readme.html#timezones"},{"type":"extras","title":"Span - ExCycle","doc":"ExCycle support `duration` (using the structs from elixir 1.17), to generates span\n\n```elixir\nExCycle.new()\n|> ExCycle.add_rule(:daily, hours: [10], duration: %Duration{hour: 2})\n```\n\nThis could be combined with `timezone` option to generate span using timezone (**with** DST support).\n\n```elixir\nExCycle.new()\n|> ExCycle.add_rule(:daily, hours: [10], duration: %Duration{hour: 2}, timezone: \"America/Montreal\")\n\n# Generates every day from 10:00 to 12:00 with timezone America/Montreal\n```","ref":"readme.html#span"},{"type":"extras","title":"Credits - ExCycle","doc":"`ExCycle` is inspired by [Cocktail](https://github.com/peek-travel/cocktail). ExCycle's goal is to improve the handling of Timezones and DST.","ref":"readme.html#credits"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}